.. meta::
    :description lang=en:
        Lists of stopwords in various languages for use in text analysis and
        text mining.

.. automodule:: advertools.stopwords
   :members:
   :undoc-members:
   :show-inheritance:
